flutter_milibris_config library
Classes
- AlertUIConfig
- Config for alert popins.
- ArticleImageUIConfig
- Config for the full-screen article image viewer.
- ArticleReaderUIConfig
- Config for the article reader.
- ArticleSettingsUIConfig
- Config for the font/brightness settings panel in the article reader.
- HtmlBoxUIConfig
- Config for HTML media boxes.
- MilibrisColor
- An adaptive color with separate light and dark variants.
- MilibrisFont
- Font specification for the Milibris reader.
- MilibrisTextConfig
- Combined color + font + line spacing for a text element.
- MilibrisUIConfig
- UI configuration for the Milibris reader.
- MiniSummaryUIConfig
- Config for the mini summary bottom sheet of the reader.
- ModalUIConfig
- Config for modal screens (e.g. search).
- Config for the reader navigation bar.
- ReaderTutorialUIConfig
- Config for the reader onboarding tutorial.
- ReaderUIConfig
- Config for top-level reader behaviour and appearance.
- SlideshowBoxUIConfig
- Config for slideshow media boxes.
- SummaryUIConfig
- Config for the full-screen summary.